package com.goldenwater.slaj.ttsa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.slaj.ttsa.mapper.BisTtsaCertArrayMapper;
import com.goldenwater.slaj.ttsa.domain.BisTtsaCertArray;
import com.goldenwater.slaj.ttsa.service.IBisTtsaCertArrayService;

@Service
public class BisTtsaCertArrayServiceImpl implements IBisTtsaCertArrayService {
    @Autowired
    private BisTtsaCertArrayMapper bisTtsaCertArrayMapper;

    @Override
    public BisTtsaCertArray selectBisTtsaCertArrayByGuid(String guid) {
        return bisTtsaCertArrayMapper.selectBisTtsaCertArrayByGuid(guid);
    }

    @Override
    public List<BisTtsaCertArray> selectBisTtsaCertArrayList(BisTtsaCertArray bisTtsaCertArray) {
        return bisTtsaCertArrayMapper.selectBisTtsaCertArrayList(bisTtsaCertArray);
    }

    @Override
    public int insertBisTtsaCertArray(BisTtsaCertArray bisTtsaCertArray) {
        return bisTtsaCertArrayMapper.insertBisTtsaCertArray(bisTtsaCertArray);
    }

    @Override
    public int updateBisTtsaCertArray(BisTtsaCertArray bisTtsaCertArray) {
        return bisTtsaCertArrayMapper.updateBisTtsaCertArray(bisTtsaCertArray);
    }

    @Override
    public int deleteBisTtsaCertArrayByGuid(String guid) {
        return bisTtsaCertArrayMapper.deleteBisTtsaCertArrayByGuid(guid);
    }

    @Override
    public int deleteBisTtsaCertArrayByGuids(String[] guids) {
        return bisTtsaCertArrayMapper.deleteBisTtsaCertArrayByGuids(guids);
    }
}
